
# Risk Factors and Adolescent Internalizing Networks --------------------------------------------


# load packages (main)-----------------------------------------------------------


library(readxl)
library(dplyr)
library(psychonetrics)
library(apaTables)
library(networktree)
library(strucchange)
library(qgraph)
library(RColorBrewer)

#NOTE: this code sometimes draws on fake fakeData (i.e. not full reproducibility)
#and sometimes runs from real bootstrapped statistics from the real fakeData (i.e.
#full reproducibility)

# steps -------------------------------------------------------------------
# 1. get correct variables/descriptives/remove missing on all- fake fakeData
# 2. create risk variables- fake fakeData
# 3. recursive partitioning- are covs different?- fake fakeData
# 4. where evidence of different covs, create bootstraps (store)- fake fakeData
# 5. use bootstraps to compare adjacency matrices- real bootstrapped stats
# 6. if adjacency matrices equal based on averaged bootstrapped, compare edge magnitude- real bootstrapped stats
# 7. calculate connectivity for each bootstrapped sample and analyse relationship group membership- real bootstrapped stats
# 8. cummulative risk: invariance, structure, connectivity- real bootstrapped stats and fake


#1. create fakeDataset with variables we need
#NA items, gender, year-group, sexuality, fam/peer support, fsm, sen, bullying, nutition items,
#physical health, eal, ethnicity, school, sex, 


#SET WORKING DIRECTORY TO FOLDER WITH FAKEDATA/BOOTSTRAPPED MATRICES SAVED
#load fake fakeData
fakeData<- read.csv("fakeDataNETCR.csv")
#relevant M&MF items: 1:4, 6:7, 9:10:
nodes<-names(fakeData)[c(8:11, 13,14,16,17)]

# descriptives etc. -------------------------------------------------------

#delete cases missing on all (effective sample size)
#eyeball:
lapply(fakefakeData[,nodes], table, useNA="ifany")
#remove missing on all network variables
fakeData<- fakeData[rowSums(is.na(fakeData[,nodes]))!=8,]# N= 34827
#double check
length(which(is.na(fakeData[,nodes[1]])&is.na(fakeData[, nodes[2]])
             &is.na(fakeData[,nodes[3]])&is.na(fakeData[,nodes[4]])
             &is.na(fakeData[,nodes[5]])&is.na(fakeData[,nodes[6]])
             &is.na(fakeData[,nodes[6]])&is.na(fakeData[,nodes[7]])
             &is.na(fakeData[,nodes[8]])))

#code below commented out since fake fakeData only generated for analysis variables, code included for completeness
# #sample characteristics (particpant section)
# dems<-lapply(lapply(fakeData[, c("gender", "year_group", "fsm", "sen",
#                              "eal", "ethnicity", "Gender", "Sexuality", "IMD_decile")], table, useNA="always"),
#              prop.table)
# dems<- 100*(data.frame(unlist(dems)))
# 
# 
# write.csv(dems, "demsOct2.csv")
# 
# length(unique(fakeData$rand_school_id))#160 schools



#fakeData assumtions outcome Negative affect
lapply(lapply(fakeData[,nodes], table, useNA="always"), prop.table)
#all show floor effects as expected but consistent with 'ordered skewed' condition from Isvoranu&Epskamp (2021)

#2. code risk factors/check N in risk (smallest) group


#to change: gender, sexuality, bullying, physical health peer/parent support
#for gender also incorporate LA sex 'gender' to ensure trans are minority
fakeData$gen<- interaction(fakeData$gender, fakeData$Gender)

fakeData$gen<- ifelse(fakeData$gen=="F.1", "CF",
                      ifelse(fakeData$gen=="M.2", "CM",
                             ifelse(is.na(fakeData$gen), NA, "MG")))
#code all binary risk variables as 0=abscent, 1= present
fakeData$genRisk<- ifelse(fakeData$gen=="CF"|fakeData$gen=="CM", 0,
                      ifelse(fakeData$gen=="MG", 1, NA))
fakeData$sexRisk<- ifelse(fakeData$Sexuality==3, 0,
                      ifelse(is.na(fakeData$Sexuality), NA, 1))

#check missingness to keep an eye on how ifelse interprets:
length(which(is.na(fakeData$Bullying1)&is.na(fakeData$Bullying2)&is.na(fakeData$Bullying3)))


fakeData$bulRisk<- ifelse(is.na(fakeData$Bullying1)&is.na(fakeData$Bullying2)&is.na(fakeData$Bullying3),NA,
                      ifelse((fakeData$Bullying1<3|is.na(fakeData$Bullying1))&(fakeData$Bullying2<3|is.na(fakeData$Bullying2))&(fakeData$Bullying3<3|is.na(fakeData$Bullying3)), 0,
                       1))
table(fakeData$bulRisk, useNA = "always")#double check

fakeData$physRisk<- ifelse(fakeData$category_physical_health==5, 1,
                       ifelse(is.na(fakeData$category_physical_health), NA, 0))

fakeData$peerRisk<- ifelse(fakeData$score_friendships_and_social_support<=8, 1,
                       ifelse(is.na(fakeData$score_friendships_and_social_support), NA, 0))
fakeData$pcRisk<- ifelse(fakeData$score_relationships_with_parents_carers<=8,1,
                     ifelse(is.na(fakeData$score_relationships_with_parents_carers), NA, 0))

fakeData$imdRisk<-ifelse(fakeData$IMD_decile==1&fakeData$fsm==1,1,
                     ifelse(is.na(fakeData$IMD_decile)|is.na(fakeData$fsm), NA, 0))


# NA for fake fakeData since already coded correctly: #recode year to 0/1:
# fakeData$year_group<- ifelse(fakeData$year_group==8, 0,
#                          ifelse(fakeData$year_group==10, 1, NA))

bins<- c("year_group", "imdRisk", "sen", "genRisk", "sexRisk", "bulRisk", "physRisk", "peerRisk", "pcRisk")
groupN<-lapply(fakeData[,bins], table)

# # simulate fakeData -----------------------------------------------------------
# This section demonstrates how the fake fakeData were generated and so is commented out in this script
# library(synthpop)
# prefake<- fakeData[,c(2,3,4, 5,8:26)]
# 
# fake<- syn(prefake, minnumlevels = 5)
# fakeData<-fake$syn
# write.csv(fakeData, "fakeData.csv", row.names = F)

#3. recursive partitioning --------------------------------------------------

treeRes<- NULL

for (i in 1:9) {
  risk<- bins[i]
  tree<- networktree(nodevars=fakeData[,nodes],
                     splitvars=fakeData[,risk],
                     method="mob",
                     bonferroni=T)
  treeRes[[i]]<- sctest(tree)
}
#code below addresses subsetting sig and non-sig results. In the real data, only bins[[2]]
#(imdRisk) is non-sig and so is treated separately. In the fake data, only bins[[9]] (pcRisk)
#is non-sig and so is treated separately. This relates to how the list is subset
diffTree<- treeRes[[9]]#only non-sig so different class to other results
otherTrees<- treeRes[-9]
otherTrees<- lapply(otherTrees, '[', 1)
otherTrees<-lapply(otherTrees, data.frame)
otherTrees<- lapply(otherTrees, t)
otherTrees<- do.call("rbind", otherTrees)
allTrees<- rbind(t(data.frame(diffTree)), otherTrees)
allTrees<- data.frame(round(allTrees, 3))
allTrees$p.value<- ifelse(allTrees$p.value==0.00, "<.001", round(allTrees$p.value,2))
allTrees$statistic<- round(allTrees$statistic,2)

write.csv(allTrees, file = "treeResIndivFAKE.csv")

# 4. create bootstrap networks --------------------------------------------
#note warnings produced in all bootstrap analysis but this but can be ignored
# relates to optimiser and convergence is achieved (local not global problem) https://cran.r-project.org/web/packages/glmmTMB/vignettes/troubleshooting.html
#to demonstrate code nboots set to 3 rather than 1000 due to computation time (real bootstrapped results
#loaded later)
nboots<- 3
toBoot<- bins[-9]#remove non-sig result (different between real/fake data)

fits<- NULL
omega<- NULL

#select risk factor
for (i in 1:8) {
  df<- fakeData[, c(toBoot[i],nodes )]
  df$group<- df[,1]#duplicate for loop but maintain original for later results naming
  riskN<-length(which(df$group==1)) 
  df1<- filter(df, group==0)
  df2<- filter(df, group==1)
  dfList<- list(df1, df2)
  
  fitj<- list()
  bootslistj<- list()
  #select group
  for (j in 1:2) {
    dfMod<- dfList[[j]]
    propr<- riskN/nrow(dfMod)
    mod<- ggm(dfMod[,nodes], estimator= "FIML", storedata=T)%>%runmodel()%>%prune()
    fit<-as.data.frame(t(fit(mod)))[2,c("df", "chisq", "pvalue", "cfi", "rmsea",
                                        "rmsea.ci.lower", "rmsea.ci.upper",
                                        "aic.ll2", "bic")]
    fit$mod<- paste(dfMod[1,1], names(dfMod)[1], sep="_")
    fitj[[j]]<- fit
    #empty list for bootstraps for ij
    listnames<- rep(fit$mod, nboots)
    boots <- vector("list", length(listnames))
    names(boots) <- listnames
    
    for (k in 1:nboots) {
      boot<-bootstrap(mod, storedata = T, prop=propr)%>%
        runmodel()%>%prune
      boots[[k]]<- boot@modelmatrices[["fullsample"]][["omega"]]
    
    }
    
    bootslistj[[j]]<-boots
   
  }
  
  fits[[i]]<- fitj
  omega[[i]]<-bootslistj

}
save(omega, file="bootOmsFAKE.RData")#save given computation time- real fakeData-generated networks can be checked for reproducibility

fitsIndiv<-do.call(rbind, do.call(c, fits))
fitsIndiv<- fitsIndiv[,c(10, 1:9)]
fitsIndiv[,2:10]<-as.numeric(unlist(fitsIndiv[,2:10]))
fitsIndiv[,3:10]<- round(fitsIndiv[,3:10], 3)


# 5. compare bootstrapped adjacency matrices ------------------------------
#draws on real bootstrapped stats:
load("bootOms.RData")
#change nboots to 1000 to run with real bootstrapped stats
nboots<- 1000
adj<-NULL
#create adjacency matrix lists (1000 per group per risk factor)
#select risk factor
for (i in 1:8) {
  r<- omega[[i]]
  #select group
  adjj<-NULL
  for (j in 1:2) {
  
  gp<- r[[j]]
  #select matrix
  adjk<-NULL
  for (k in 1:nboots) {
    mat<- gp[[k]]
    adjk[[k]]<- 1*(mat!=0)
    names(adjk)[k]<- names(gp[k])
  }
  adjj[[j]]<- adjk
  }
  adj[[i]]<-adjj

}
#create summary adjacency (1 per group per risk factor)
finadj<- NULL
for (i in 1:8) {
  rf<- adj[[i]]
  sumadj<- NULL
  for (j in 1:2) {
    gp<- rf[[j]]
    sum<- Reduce("+", gp)
    sumadj[[j]]<-ifelse(sum>=length(gp)/2,1,0)
    names(sumadj)[j]<- names(gp[j])
  }
  finadj[[i]]<- sumadj
}

#compare adjacency matrices between groups within risk factor
lapply(finadj, function(x) identical(x[1], x[2]))
#conclude structure is different across groups consistent with recursive partitioning
#omit stage 6

#visualise networks for each group


toPlot<- NULL
for (i in 1:8) {
  #select risk factor
  r<- omega[[i]]
  a<- finadj[[i]]
  #empty list for average j mat
  listnamestp<- lapply(r, names)
  listnamestp<- lapply(listnamestp,"[", 1)
  aveG <- vector("list", length(listnamestp))
  names(aveG) <- listnamestp
  #select group
  for (j in 1:2) {
    g<- r[[j]]
    ag<- a[[j]]
    for (k in 1:nboots) {
      toZeros<- which(ag==0, arr.ind = T)
      g[[k]][toZeros]<-0
    }
    aveG[[j]]<- Reduce("+", g) / length(g)
  }
  toPlot[[i]]<- aveG
}

nodenames<- c("lonely", "unhappy", "unliked",
              "cry", "worry", "sleep", "shy", "scared")
#check relative densities 
densities<- NULL
for (i in 1:8) {
  rd<- finadj[[i]]
  #28= possible connections ((8*7)/2)
  g0Dens<- paste(round(100*(Reduce("+", rd[[1]][lower.tri(rd[[1]])])/28),2), "%", sep= "")
  g1Dens<- paste(round(100*(Reduce("+", rd[[2]][lower.tri(rd[[2]])])/28),2), "%", sep= "")
  densities[[i]]<- list("zero"= g0Dens, "risk"= g1Dens)
}

densities

pdf("panelPlotIndiv.pdf",width=8.27, height=11.69)

par(mfrow=c(4,2), mar=c(.05, .05, .05, .05))

layout<- averageLayout(toPlot)
plotCols<- brewer.pal(8, "Dark2")

titles1<- rep(c("No Risk Group","Risk Group"), 8) 
titles2<- c("Age", "SEN", "Gender Minority", "Sexual Minority", "Bullied",
            "Physical Health", "Peer Relationships", "Parent/Carer")
titles2<- unlist(lapply(titles2, rep, 2))
minP<- NULL
maxP<-NULL
for (i in 1:8) {
  mat<- toPlot[[i]]
  minP[[i]]<- list(substr(min(abs(mat[[1]][mat[[1]]>0])),2,4), substr(min(abs(mat[[2]][mat[[2]]>0])),2,4))
  maxP[[i]]<- list(substr(max(abs(mat[[1]])),2,4), substr(max(abs(mat[[2]])),2,4))
    
}
titles<- paste(titles1, titles2, paste("Density =", unlist(densities), sep = " "),
               paste("min =", unlist(minP), sep= " "),
               paste("max =", unlist(maxP), sep = " "),
               sep = ", ")
titles<- lapply(split(titles, rep(1:8, each = 2)), split, 1:2)
plots<- NULL
for (i in 1:8) {
  rp<- toPlot[[i]]
  max<- max(c(abs(rp[[1]]), abs(rp[[2]])))
  p1<-qgraph(rp[[1]],
             edge.color= plotCols[[i]], 
             maximum= max,
             labels= nodenames,
             layout= layout, 
             title= titles[[i]][1],
             legend = FALSE
             
  )
  p2<- qgraph(rp[[2]],
              edge.color= plotCols[[i]],
              maximum= max,
              labels= nodenames,
              layout= layout, 
              title= titles[[i]][2],
              legend = FALSE
             
  )
  plots[[i]]<- list(p1, p2)
}
dev.off()


# 7. connectivity for individual risk factors

conMods<- list()


#select risk factor
for (i in 1:8) {
  #select risk factor
  om<- omega[[i]]
  conDf<-NULL
  #select group
  for (j in 1:2) {
    omg<- om[[j]]
   
    connectivity<-unlist(lapply(omg, function(x) sum(abs(x[upper.tri(x)]))))
    conDf[[j]]<-data.frame(connectivity=connectivity, group= names(omg))
  }
  cons<- do.call("rbind", conDf)
  lmod<- lm(connectivity~group, data = cons) #Create the linear regression
  conMods[[i]]<-apa.reg.table(lmod)[["table_body"]]
  }

indivds<- do.call("rbind", conMods)

# this section is commented out since fake/real data are different for which 
#risk factors are sig/non-sig in tree analysis. Code below demonstrates how
#imd bootstraps were generated (omitied in omega loop in real data since non-sig)
#the real data bootstraps are loaded later to reproduce the results
# #7. create omega bootstraps and consider connectivity for IMD
# #(separate since not boostraps not estimated after ns RP)
# imd0<- filter(fakeData, imdRisk==0)
# imd1<- filter(fakeData, imdRisk==1)
# imdList<- list(imd0, imd1)
# bootslistIMD<- NULL
# fitIMD<-NULL
# 
# #create bootstrapped omegas
# for (j in 1:2) {
#   dfMod<- imdList[[j]]
#   propr<- 6365/nrow(dfMod)#6365=risk N
#   mod<- ggm(dfMod[,nodes], estimator= "FIML", storedata=T)%>%runmodel()%>%prune()
#   fit<-as.data.frame(t(fit(mod)))[2,c("df", "chisq", "pvalue", "cfi", "rmsea",
#                                       "rmsea.ci.lower", "rmsea.ci.upper",
#                                       "aic.ll2", "bic")]
#   fit$mod<- paste("IMD", dfMod[1,34], sep="_")
#   fitIMD[[j]]<- fit
#   #empty list for bootstraps for ij
#   
#   listnames<- rep(fit$mod, nboots)
#   boots <- vector("list", length(listnames))
#   names(boots) <- listnames
#   
#   for (k in 1:nboots) {
#     boot<-bootstrap(mod, storedata = T, prop=propr)%>%
#       runmodel()%>%prune
#     boots[[k]]<- boot@modelmatrices[["fullsample"]][["omega"]]
#    
#   }
#   
#   bootslistIMD[[j]]<-boots
#  
# }
# 
# save(bootslistIMD, file="bootIMDOms.RData")#save given computation time- real fakeData-generated networks can be checked for reproducibility
# #add IMD indiviudal group fits to table and write to csv for supplement:
# fitsIMD<-do.call(rbind, fitIMD)
# fitsIMD<- fitsIMD[,c(10, 1:9)]
# fitsIMD[,2:10]<-as.numeric(unlist(fitsIMD[,2:10]))
# fitsIMD[,3:10]<- round(fitsIMD[,3:10], 3)
# fitsIndiv<- rbind(fitsIndiv, fitsIMD)


#connectivity
load("bootIMDOms.RData")#use if not running bootstraps and to draw on real fakeData results for reproducibility
conDfIMD<- NULL

  #select group
  for (j in 1:2) {
    omg<- bootslistIMD[[j]]
    connectivity<-unlist(lapply(omg, function(x) sum(abs(x[upper.tri(x)]))))
    conDfIMD[[j]]<-data.frame(connectivity=connectivity, group= names(omg))
  }
  consIMD<- do.call("rbind", conDfIMD)
  lmodIMD<- lm(connectivity~group, data = consIMD) #Create the linear regression
  conModsIMD<-apa.reg.table(lmodIMD)[["table_body"]]

indivds<- rbind(indivds, conModsIMD)
write.csv(indivds, "individualLM.csv" )

#8. CR

#create CR variable:
#this section demonstrates calculation of CR using fake data, (indices match fakeData names):
fakeData$cr<- rowSums(fakeData[,c(2,4,25:31)], na.rm=T)
length(which(is.na(fakeData[,2])&is.na(fakeData[,4])
             &is.na(fakeData[,25])&is.na(fakeData[,26])&is.na(fakeData[,27])
             &is.na(fakeData[,29])&is.na(fakeData[,28])
             &is.na(fakeData[,30])&is.na(fakeData[,31])))#no participants have missing on all so no missing for CR

table(fakeData$cr, useNA="always")#collapse 5+

fakeData$cr<- ifelse(fakeData$cr==1,1,
                 ifelse(fakeData$cr==2,2,
                        ifelse(fakeData$cr==3,3,
                               ifelse(fakeData$cr==0, 0,
                               ifelse(fakeData$cr==4,4, 5)))))

#recursive partioning to identify splits
treeCR<- networktree(nodevars=fakeData[,nodes],
                     splitvars=fakeData[,"cr"],
                     method="mob",
                     bonferroni=T)
treeResCR<- sctest(treeCR)
#fakedata plot is different to real data since pattern of sig trees is different 
#(only 5 groups in fake compared to 6 in real)
pdf("treeCRFAKE.pdf")

plot(treeCR)
dev.off()

#demonstration of code to create bootstraps for CR, reset nboots to 3 for computation reasons
#since lm is run within loop for efficiency, real results for connectivity~cr not reproducible
#structure CR results are reproducible
nboots<- 3
bootsCR6<- NULL
conDfcr<- NULL
fitcr<-NULL
ind<- 0:5
 for(i in 1:6){
   df<-filter(fakeData, cr==ind[i])
   mod<- ggm(df[,nodes], estimator= "FIML", storedata=T)%>%runmodel()%>%prune()
   fit<-as.data.frame(t(fit(mod)))[2,c("df", "chisq", "pvalue", "cfi", "rmsea",
   "rmsea.ci.lower", "rmsea.ci.upper",
  "aic.ll2", "bic")]
   fit$mod<- paste("CR", df[1,32], sep="_")
  fitcr[[i]]<- fit
  ns<- as.vector(table(fakeData$cr))
  min<- min(ns)
  prop<- min/ns[i]
listnamesCR<- rep(paste("cr", df[1,32], sep="_"), nboots)
boots <- vector("list", length(listnamesCR))
names(boots) <- listnamesCR
   ns<- as.vector(table(fakeData$cr))
   
   min<- min(ns)
   prop<- min/ns[i]
   for (j in 1:nboots) {
     boot<-bootstrap(mod, storedata = T, proportion = prop)%>%
       runmodel()%>%prune
     boots[[j]]<- boot@modelmatrices[["fullsample"]][["omega"]]
     
  }
  bootsCR6[[i]]<- boots 
   connectivity<-unlist(lapply(boots, function(x) sum(abs(x[upper.tri(x)]))))
   conDfcr[[i]]<-data.frame(connectivity=connectivity, group= rep(paste(df[1,32], "cr", sep="_"), nboots))
   
 }

fitcr<-do.call(rbind, fitcr)
fitcr<- fitcr[,c(10, 1:9)]
fitcr[,2:10]<-as.numeric(unlist(fitcr[,2:10]))
fitcr[,3:10]<- round(fitcr[,3:10], 3)
fitsIndiv<- rbind(fitsIndiv, fitcr)
write.csv(fitsIndiv, "indidualFullSampleFitsFAKE.csv")

save(bootsCR6, file= "bootscr6FAKE.RData")

#load real bootstrapped stats for structure to reproduce
load("bootscr6.RData")
#reset nboots to 1000 to run with real bootsrapped stats:
nboots<- 1000

adjCR<- NULL
for (j in 1:6) {
  
  level<- bootsCR6[[j]]
  #select matrix
  adjkCR<-NULL
  for (k in 1:nboots) {
    mt<- level[[k]]
    adjkCR[[k]]<- 1*(mt!=0)
    names(adjkCR)[k]<- names(level[k])
  }
  adjCR[[j]]<- adjkCR
}


#create summary adjacency (1 per group per level)
finadjCR<- NULL
for (i in 1:6) {
  lev<- adjCR[[i]]
  sum<- Reduce("+", lev)
  finadjCR[[i]]<-ifelse(sum>=length(lev)/2,1,0)
  names(finadjCR)[i]<- names(lev)[1]
  
  
}

#compare adjacency matrices between levels
adjResCR<- NULL
for (i in 1:6) {
  adjResCR[[i]]<-sapply(finadjCR, FUN = identical, finadjCR[[i]])
}
lapply(adjResCR, sum, na.rm=T)
adjResCR
#no pairs are the same

#visualize networks across levels of cr

toPlotcr<- NULL
#select level
for (j in 1:6) {
  l<- bootsCR6[[j]]
  al<- finadjCR[[j]]
  for (k in 1:nboots) {
    toZeros<- which(al==0, arr.ind = T)
    l[[k]][toZeros]<-0
  }
  toPlotcr[[j]]<- Reduce("+", l) / length(l)
  names(toPlotcr)[j]<- names(l)[1]
}


#check relative densities 
densitiesCR<- NULL
for (i in 1:6) {
  ld<- finadjCR[[i]]
  #28= possible connections ((8*7)/2)
  densitiesCR[[i]]<- paste(round(100*(Reduce("+", ld[lower.tri(ld)])/28),2), "%", sep= "")
  names(densitiesCR[[i]])<- names(finadjCR)[i]
}

densitiesCR

minCRp<-NULL
maxCRp<- NULL

for (i in 1:6) {
  matcr<- toPlotcr[[i]]
  minCRp[[i]]<- substr(min(abs(matcr[matcr>0])),2,4)
  maxCRp[[i]]<- substr(max(abs(matcr)),2,4)
  
}

pdf("panelPlotCR.pdf",width = 8, height = 14)
par(mfrow= c(3,2))

layoutcr<- averageLayout(toPlotcr)
maxCR<- max(c(abs(toPlotcr[[1]]), abs(toPlotcr[[2]]), abs(toPlotcr[[3]]),
              abs(toPlotcr[[4]]), abs(toPlotcr[[5]]), abs(toPlotcr[[6]])))

titlesCR1<- c("0 Risk Factors", "1 Risk Factor", paste(2:4, "Risk Factors", sep = " "), "5+ Risk Factors")
titlesCR<- paste(titlesCR1, paste("Density =", unlist(densitiesCR), sep=" "),
                 paste("min =", unlist(minCRp), sep = " "),
                 paste("max =", unlist(maxCRp), sep = " ")
                 ,sep = ", ")
plotscr<- NULL
for (i in 1:6) {
  lp<- toPlotcr[[i]]
  
  plotscr[[i]]<- qgraph(lp,
                        theme = "Hollywood", 
                        maximum= maxCR,
                        labels= nodenames,
                        layout= layoutcr, 
                        title= titlesCR[i],
                        label.cex = 1.1,
                        legend = FALSE
  )
}
dev.off()

#fake prediction model
 consCR<- do.call("rbind", conDfcr)
 table(consCR$group)

 #recode group var
consCR$group<- (as.numeric(factor(consCR$group))-1)
 lmodcr<- lm(connectivity~group, data = consCR)
 crRes<-apa.reg.table(lmodcr)[["table_body"]]
 
 
 crquad<- lm(connectivity~poly(group,2), data = consCR)
 apa.reg.table(crquad) #to get R2 CIs
 
 
crcub<- lm(connectivity~poly(group,3), data = consCR)
apa.reg.table(crcub)

 
 write.csv(crRes, "CRresFAKE.csv")
 



